@@ -7,19 +7,20 @@ import functools
 
 import numpy as np
 import pyproj
+import shapely.geometry
 from scipy.spatial.ckdtree import cKDTree
 
 from .ops import create_rotation_matrix
 
-""" Geometric transformation ------------------------------------------------------------ """
+""" Geometric transformation ----------------------------------------------------------------- """
 
 
 # Geometric type
 
 def transform_geom_point_type(*pts, as_geom=True):
     """
-    Transform iterable to `shapely.geometry.Point
-    <https://shapely.readthedocs.io/en/latest/manual.html#points>`_ type,
+    Transform iterable to
+    `shapely.geometry.Point <https://shapely.readthedocs.io/en/latest/manual.html#points>`_ type,
     or the other way round.
 
     :param pts: points (e.g. list of lists/tuples or shapely.geometry.Points)
@@ -29,6 +30,8 @@ def transform_geom_point_type(*pts, as_geom=True):
     :return: a sequence of points (incl. None, if errors occur)
     :rtype: types.GeneratorType
 
+    .. _`shapely.geometry.Point`: https://shapely.readthedocs.io/en/latest/manual.html#points
+
     **Examples**::
 
         >>> from pyhelpers.geom import transform_geom_point_type
@@ -37,50 +40,43 @@ def transform_geom_point_type(*pts, as_geom=True):
         >>> pt_y = 1.4909, 52.6271
 
         >>> geom_points = transform_geom_point_type(pt_x, pt_y)
-        >>> for x in geom_points:
-        ...     print(x)
+        >>> for x in geom_points: print(x)
         POINT (1.5429 52.6347)
         POINT (1.4909 52.6271)
 
         >>> geom_points = transform_geom_point_type(pt_x, pt_y, as_geom=False)
-        >>> for x in geom_points:
-        ...     print(x)
+        >>> for x in geom_points: print(x)
         (1.5429, 52.6347)
         (1.4909, 52.6271)
 
         >>> from shapely.geometry import Point
 
-        >>> pt_x = Point(pt_x)
-        >>> pt_y = Point(pt_y)
+        >>> pt_x, pt_y = Point(pt_x), Point(pt_y)
 
         >>> geom_points = transform_geom_point_type(pt_x, pt_y)
-        >>> for x in geom_points:
-        ...     print(x)
+        >>> for x in geom_points: print(x)
         POINT (1.5429 52.6347)
         POINT (1.4909 52.6271)
 
         >>> geom_points = transform_geom_point_type(pt_x, pt_y, as_geom=False)
-        >>> for x in geom_points:
-        ...     print(x)
+        >>> for x in geom_points: print(x)
         (1.5429, 52.6347)
         (1.4909, 52.6271)
     """
 
-    from shapely.geometry import Point
-
     if as_geom:
         for pt in pts:
-            if isinstance(pt, Point):
+            if isinstance(pt, shapely.geometry.Point):
                 pt_ = pt
             elif isinstance(pt, collections.abc.Iterable):
                 assert len(list(pt)) == 2
-                pt_ = Point(pt)
+                pt_ = shapely.geometry.Point(pt)
             else:
                 pt_ = None
             yield pt_
     else:
         for pt in pts:
-            if isinstance(pt, Point):
+            if isinstance(pt, shapely.geometry.Point):
                 pt_ = pt.x, pt.y
             elif isinstance(pt, collections.abc.Iterable):
                 assert len(list(pt)) == 2
@@ -94,10 +90,8 @@ def transform_geom_point_type(*pts, as_geom=True):
 
 def wgs84_to_osgb36(longitude, latitude, **kwargs):
     """
-    Convert latitude and longitude
-    (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_)
-    to British national grid
-    (`OSGB36 <https://en.wikipedia.org/wiki/Ordnance_Survey_National_Grid>`_).
+    Convert latitude and longitude (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_)
+    to British national grid (`OSGB36 <https://en.wikipedia.org/wiki/Ordnance_Survey_National_Grid>`_).
 
     :param longitude: the longitude (abbr: long., λ, or lambda) of a point on Earth's surface
     :type longitude: float or int
@@ -112,12 +106,12 @@ def wgs84_to_osgb36(longitude, latitude, **kwargs):
 
         >>> from pyhelpers.geom import wgs84_to_osgb36
 
-        >>> long, lat = -0.12772404, 51.507407
+        >>> lon, lat = -0.1277, 51.5074
 
-        >>> x, y = wgs84_to_osgb36(long, lat)
+        >>> x, y = wgs84_to_osgb36(lon, lat)
 
         >>> print("(Easting, Northing): {}".format((x, y)))
-        (Easting, Northing): (530033.99829712, 180381.00751935126)
+        (Easting, Northing): (530035.6864715678, 180380.27177236252)
     """
 
     wgs84 = 'EPSG:4326'  # LonLat with WGS84 datum used by GPS units and Google Earth
@@ -133,8 +127,7 @@ def osgb36_to_wgs84(easting, northing, **kwargs):
     """
     Convert British national grid
     (`OSGB36 <https://en.wikipedia.org/wiki/Ordnance_Survey_National_Grid>`_)
-    to latitude and longitude
-    (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_).
+    to latitude and longitude (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_).
 
     :param easting: Easting (X), eastward-measured distance (or the x-coordinate)
     :type easting: int or float
@@ -151,10 +144,10 @@ def osgb36_to_wgs84(easting, northing, **kwargs):
 
         >>> x, y = 530034, 180381
 
-        >>> long, lat = osgb36_to_wgs84(x, y)
+        >>> lon, lat = osgb36_to_wgs84(x, y)
 
-        >>> print("(Longitude, Latitude): {}".format((long, lat)))
-        (Longitude, Latitude): (-0.12772400574286874, 51.50740692743041)
+        >>> print("(Longitude, Latitude): {}".format((lon, lat)))
+        (Longitude, Latitude): (-0.12772400574286916, 51.50740692743041)
     """
 
     osgb36 = 'EPSG:27700'  # UK Ordnance Survey, 1936 datum
@@ -168,10 +161,8 @@ def osgb36_to_wgs84(easting, northing, **kwargs):
 
 def wgs84_to_osgb36_calc(longitude, latitude):
     """
-    Convert latitude and longitude
-    (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_)
-    to British national grid
-    (`OSGB36 <https://en.wikipedia.org/wiki/Ordnance_Survey_National_Grid>`_)
+    Convert latitude and longitude (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_)
+    to British national grid (`OSGB36 <https://en.wikipedia.org/wiki/Ordnance_Survey_National_Grid>`_)
     by calculation.
 
     :param longitude: the longitude (abbr: long., λ, or lambda) of a point on Earth's surface
@@ -185,19 +176,19 @@ def wgs84_to_osgb36_calc(longitude, latitude):
 
         >>> from pyhelpers.geom import wgs84_to_osgb36_calc
 
-        >>> long, lat = -0.12772404, 51.507407
+        >>> lon, lat = -0.1277, 51.5074
 
-        >>> easting, northing = wgs84_to_osgb36_calc(long, lat)
+        >>> easting, northing = wgs84_to_osgb36_calc(lon, lat)
 
         >>> print("(Easting, Northing): {}".format((easting, northing)))
-        (Easting, Northing): (530034.0010406997, 180381.0084845958)
+        (Easting, Northing): (530035.689215283, 180380.27273760783)
 
     .. note::
 
         - This function is slightly modified from the original code available at
           [`GEOM-WTOC-1 <http://blogs.casa.ucl.ac.uk/2014/12/26/>`_].
 
-        - Compare also :ref:`wgs84_to_osgb36(long, lat)<wgs84_to_osgb36-example>`.
+        - Compare also :ref:`wgs84_to_osgb36(lon, lat)<wgs84_to_osgb36-example>`.
     """
 
     # First convert to radians. These are on the wrong ellipsoid currently: GRS80.
@@ -265,8 +256,7 @@ def wgs84_to_osgb36_calc(longitude, latitude):
     eta2 = nu * f0 / rho - 1
 
     m1 = (1 + y + (5 / 4) * y ** 2 + (5 / 4) * y ** 3) * (latitude - lat0)
-    m2 = (3 * y +
-          3 * y ** 2 + (21 / 8) * y ** 3) * np.sin(latitude - lat0) * np.cos(latitude + lat0)
+    m2 = (3 * y + 3 * y ** 2 + (21 / 8) * y ** 3) * np.sin(latitude - lat0) * np.cos(latitude + lat0)
     m3 = ((15 / 8) * y ** 2 +
           (15 / 8) * y ** 3) * np.sin(2 * (latitude - lat0)) * np.cos(2 * (latitude + lat0))
     m4 = (35 / 24) * y ** 3 * np.sin(3 * (latitude - lat0)) * np.cos(3 * (latitude + lat0))
@@ -286,10 +276,9 @@ def wgs84_to_osgb36_calc(longitude, latitude):
             5 - 18 * np.tan(latitude) ** 2 + np.tan(latitude) ** 4 + 14 * eta2 -
             58 * eta2 * np.tan(latitude) ** 2) / 120
 
-    y = i + ii * (longitude - lon0) ** 2 + \
-        iii * (longitude - lon0) ** 4 + iii_a * (longitude - lon0) ** 6
-    x = e0 + iv * (longitude - lon0) + \
-        v * (longitude - lon0) ** 3 + vi * (longitude - lon0) ** 5
+    y = i + ii * (longitude - lon0) ** 2 + iii * (
+            longitude - lon0) ** 4 + iii_a * (longitude - lon0) ** 6
+    x = e0 + iv * (longitude - lon0) + v * (longitude - lon0) ** 3 + vi * (longitude - lon0) ** 5
 
     return x, y
 
@@ -298,8 +287,7 @@ def osgb36_to_wgs84_calc(easting, northing):
     """
     Convert british national grid
     (`OSGB36 <https://en.wikipedia.org/wiki/Ordnance_Survey_National_Grid>`_)
-    to latitude and longitude
-    (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_)
+    to latitude and longitude (`WGS84 <https://en.wikipedia.org/wiki/World_Geodetic_System>`_)
     by calculation.
 
     :param easting: Easting (X), eastward-measured distance (or the x-coordinate)
@@ -347,8 +335,7 @@ def osgb36_to_wgs84_calc(easting, northing):
     while northing - n0 - m >= 0.00001:  # Accurate to 0.01mm
         lat += (northing - n0 - m) / (a * f0)
         m1 = (1 + n + (5. / 4) * n ** 2 + (5. / 4) * n ** 3) * (lat - lat0)
-        m2 = (3 * n + 3 * n ** 2 +
-              (21. / 8) * n ** 3) * np.sin(lat - lat0) * np.cos(lat + lat0)
+        m2 = (3 * n + 3 * n ** 2 + (21. / 8) * n ** 3) * np.sin(lat - lat0) * np.cos(lat + lat0)
         m3 = ((15. / 8) * n ** 2 + (15. / 8) * n ** 3) * np.sin(
             2 * (lat - lat0)) * np.cos(2 * (lat + lat0))
         m4 = (35. / 24) * n ** 3 * np.sin(3 * (lat - lat0)) * np.cos(3 * (lat + lat0))
@@ -371,8 +358,8 @@ def osgb36_to_wgs84_calc(easting, northing):
     x_ = sec_lat / nu
     xi = sec_lat / (6 * nu ** 3) * (nu / rho + 2 * np.tan(lat) ** 2)
     xii = sec_lat / (120 * nu ** 5) * (5 + 28 * np.tan(lat) ** 2 + 24 * np.tan(lat) ** 4)
-    xiia = sec_lat / (5040 * nu ** 7) * (61 + 662 * np.tan(lat) ** 2 +
-                                         1320 * np.tan(lat) ** 4 + 720 * np.tan(lat) ** 6)
+    xiia = sec_lat / (5040 * nu ** 7) * (
+            61 + 662 * np.tan(lat) ** 2 + 1320 * np.tan(lat) ** 4 + 720 * np.tan(lat) ** 6)
     de = easting - e0
 
     # These are on the wrong ellipsoid currently: Airy1830. (Denoted by _1)
@@ -414,20 +401,20 @@ def osgb36_to_wgs84_calc(easting, northing):
         lat = np.arctan2(z_2 + e2_2 * nu_2 * np.sin(lat_old), p)
 
     # Lon and height are then pretty easy
-    long = np.arctan2(y_2, x_2)
+    lon = np.arctan2(y_2, x_2)
     # h = p / cos(lat) - nu_2
 
     # Print the results
     # print([(lat - lat_1) * 180 / pi, (lon - lon_1) * 180 / pi])
 
     # Convert to degrees
-    long = long * 180 / np.pi
+    lon = lon * 180 / np.pi
     lat = lat * 180 / np.pi
 
-    return long, lat
+    return lon, lat
 
 
-""" Geometry calculation ---------------------------------------------------------------- """
+""" Geometry calculation --------------------------------------------------------------------- """
 
 
 # Distance
@@ -454,8 +441,7 @@ def calc_distance_on_unit_sphere(pt_x, pt_y):
 
         >>> from pyhelpers.geom import calc_distance_on_unit_sphere
 
-        >>> pt_1 = 1.5429, 52.6347
-        >>> pt_2 = 1.4909, 52.6271
+        >>> pt_1, pt_2 = (1.5429, 52.6347), (1.4909, 52.6271)
 
         >>> arc_len = calc_distance_on_unit_sphere(pt_1, pt_2)
         >>> print(arc_len)
@@ -465,12 +451,10 @@ def calc_distance_on_unit_sphere(pt_x, pt_y):
     # Convert latitude and longitude to spherical coordinates in radians.
     degrees_to_radians = np.pi / 180.0
 
-    from shapely.geometry import Point
-
-    if not all(isinstance(x, Point) for x in (pt_x, pt_y)):
+    if not all(isinstance(x, shapely.geometry.Point) for x in (pt_x, pt_y)):
         try:
-            pt_x = Point(pt_x)
-            pt_y = Point(pt_y)
+            pt_x = shapely.geometry.Point(pt_x)
+            pt_y = shapely.geometry.Point(pt_y)
         except Exception as e:
             print(e)
             return None
@@ -490,8 +474,7 @@ def calc_distance_on_unit_sphere(pt_x, pt_y):
     # cosine( arc length ) = sin phi sin phi' cos(theta-theta') + cos phi cos phi'
     # distance = rho * arc length
 
-    cosine = (np.sin(phi1) * np.sin(phi2) * np.cos(theta1 - theta2) +
-              np.cos(phi1) * np.cos(phi2))
+    cosine = (np.sin(phi1) * np.sin(phi2) * np.cos(theta1 - theta2) + np.cos(phi1) * np.cos(phi2))
     arc_length = np.arccos(cosine) * 3960  # in miles
 
     # To multiply arc by the radius of the earth in a set of units to get length.
@@ -500,8 +483,7 @@ def calc_distance_on_unit_sphere(pt_x, pt_y):
 
 def calc_hypotenuse_distance(pt_x, pt_y):
     """
-    Calculate hypotenuse given two points
-    (the right angled triangle, given its side and perpendicular).
+    Calculate hypotenuse given two points (the right angled triangle, given its side and perpendicular).
 
     :param pt_x: a point
     :type pt_x: shapely.geometry.Point or list or tuple or numpy.ndarray
@@ -516,15 +498,13 @@ def calc_hypotenuse_distance(pt_x, pt_y):
 
         ``numpy.hypot(x, y)`` return the Euclidean norm, ``sqrt(x*x + y*y)``.
 
-        See also [`GEOM-CHD-1
-        <https://numpy.org/doc/stable/reference/generated/numpy.hypot.html>`_].
+        See also [`GEOM-CHD-1 <https://numpy.org/doc/stable/reference/generated/numpy.hypot.html>`_].
 
     **Example**::
 
         >>> from pyhelpers.geom import calc_hypotenuse_distance
 
-        >>> pt_1 = 1.5429, 52.6347
-        >>> pt_2 = 1.4909, 52.6271
+        >>> pt_1, pt_2 = (1.5429, 52.6347), (1.4909, 52.6271)
 
         >>> hypot_distance = calc_hypotenuse_distance(pt_1, pt_2)
         >>> print(hypot_distance)
@@ -545,7 +525,7 @@ def find_closest_point(pt, ref_pts, as_geom=False):
     Find the closest point of the given point to a list of points.
 
     :param pt: (longitude, latitude)
-    :type pt: tuple, list
+    :type pt: tuple or list
     :param ref_pts: a sequence of reference (tuple/list of length 2) points
     :type ref_pts: tuple or list or iterable
     :param as_geom: whether to return `shapely.geometry.Point`_, defaults to ``False``
@@ -560,9 +540,10 @@ def find_closest_point(pt, ref_pts, as_geom=False):
         >>> from pyhelpers.geom import find_closest_point
 
         >>> pt_x = (2.5429, 53.6347)
-        >>> pt_reference = ((1.5429, 52.6347),
+
+        >>> pt_reference = [(1.5429, 52.6347),
         ...                 (1.4909, 52.6271),
-        ...                 (1.4248, 52.63075))
+        ...                 (1.4248, 52.63075)]
 
         >>> pt_closest = find_closest_point(pt_x, pt_reference)
         >>> print(pt_closest)
@@ -571,9 +552,10 @@ def find_closest_point(pt, ref_pts, as_geom=False):
         >>> from shapely.geometry import Point
 
         >>> pt_x = Point((2.5429, 53.6347))
-        >>> pt_reference = (Point((1.5429, 52.6347)),
+
+        >>> pt_reference = [Point((1.5429, 52.6347)),
         ...                 Point((1.4909, 52.6271)),
-        ...                 Point((1.4248, 52.63075)))
+        ...                 Point((1.4248, 52.63075))]
 
         >>> pt_closest = find_closest_point(pt_x, pt_reference)
         >>> print(pt_closest)
@@ -584,11 +566,9 @@ def find_closest_point(pt, ref_pts, as_geom=False):
         POINT (1.5429 52.6347)
     """
 
-    from shapely.geometry import Point
+    pt_ = (pt.x, pt.y) if isinstance(pt, shapely.geometry.Point) else pt
 
-    pt_ = (pt.x, pt.y) if isinstance(pt, Point) else pt
-
-    if any(isinstance(x, Point) for x in ref_pts):
+    if any(isinstance(x, shapely.geometry.Point) for x in ref_pts):
         ref_pts_ = ((pt.x, pt.y) for pt in ref_pts)
     else:
         ref_pts_ = ref_pts
@@ -597,29 +577,28 @@ def find_closest_point(pt, ref_pts, as_geom=False):
     closest_point = min(ref_pts_, key=functools.partial(calc_hypotenuse_distance, pt_))
 
     if as_geom:
-        closest_point = Point(closest_point)
+        closest_point = shapely.geometry.Point(closest_point)
 
     return closest_point
 
 
 def find_closest_points(pts, ref_pts, k=1, as_geom=False, **kwargs):
     """
-    Find the closest points from a given list of reference points
-    (applicable for vectorized computation).
+    Find the closest points from a list of reference points (applicable for vectorized computation).
 
     See also [`GEOM-FCPB-1 <https://gis.stackexchange.com/questions/222315>`_].
 
-    :param pts: an array of points
-    :type pts: numpy.ndarray [of size (n, 2)]
-    :param ref_pts: an array of reference points
-    :type ref_pts: numpy.ndarray [of size (n, 2)]
+    :param pts: an array (of size (n, 2)) of points
+    :type pts: numpy.ndarray
+    :param ref_pts: an array (of size (n, 2)) of reference points
+    :type ref_pts: numpy.ndarray
     :param k: (up to) the ``k``-th nearest neighbour(s), defaults to ``1``
-    :type k: integer, list of integer
+    :type k: int or list
     :param as_geom: whether to return `shapely.geometry.Point`_, defaults to ``False``
     :type as_geom: bool
     :param kwargs: optional parameters of `scipy.spatial.cKDTree`_
     :return: the closest point(s)
-    :rtype: numpy.ndarray, list
+    :rtype: numpy.ndarray or list
 
     .. _`shapely.geometry.Point`:
         https://shapely.readthedocs.io/en/latest/manual.html#points
@@ -646,8 +625,7 @@ def find_closest_points(pts, ref_pts, k=1, as_geom=False, **kwargs):
          [ 2.4248  53.63075]]
 
         >>> pts_closest = find_closest_points(pt_x, pt_reference, k=1, as_geom=True)
-        >>> for x in pts_closest:
-        ...     print(x)
+        >>> for x in pts_closest: print(x)
         POINT (2.4248 53.63075)
         POINT (2.4248 53.63075)
         POINT (2.4248 53.63075)
@@ -662,8 +640,8 @@ def find_closest_points(pts, ref_pts, k=1, as_geom=False, **kwargs):
     distances, indices = ref_ckd_tree.query(pts, k=k)  # returns (distance, index)
 
     if as_geom:
-        from shapely.geometry import Point
-        closest_points = [Point(ref_pts_[i]) for i in indices]
+
+        closest_points = [shapely.geometry.Point(ref_pts_[i]) for i in indices]
     else:
         closest_points = np.array([ref_pts_[i] for i in indices])
 
@@ -717,8 +695,7 @@ def get_midpoint(x1, y1, x2, y2, as_geom=False):
          [ 1.9909 53.1271]]
 
         >>> midpt = get_midpoint(x_1, y_1, x_2, y_2, as_geom=True)
-        >>> for pt in midpt:
-        ...    print(pt)
+        >>> for pt in midpt: print(pt)
         POINT (2.0429 53.1347)
         POINT (1.9909 53.1271)
     """
@@ -727,12 +704,12 @@ def get_midpoint(x1, y1, x2, y2, as_geom=False):
 
     if as_geom:
 
-        from shapely.geometry import Point
-
         if all(isinstance(x, np.ndarray) for x in mid_pts):
-            midpoint = [Point(x_, y_) for x_, y_ in zip(list(mid_pts[0]), list(mid_pts[1]))]
+            midpoint = [
+                shapely.geometry.Point(x_, y_) for x_, y_ in zip(list(mid_pts[0]), list(mid_pts[1]))
+            ]
         else:
-            midpoint = Point(mid_pts)
+            midpoint = shapely.geometry.Point(mid_pts)
 
     else:
         midpoint = np.array(mid_pts).T
@@ -761,8 +738,7 @@ def get_geometric_midpoint(pt_x, pt_y, as_geom=False):
 
         >>> from pyhelpers.geom import get_geometric_midpoint
 
-        >>> pt_1 = 1.5429, 52.6347
-        >>> pt_2 = 1.4909, 52.6271
+        >>> pt_1, pt_2 = (1.5429, 52.6347), (1.4909, 52.6271)
 
         >>> geometric_midpoint = get_geometric_midpoint(pt_1, pt_2)
         >>> print(geometric_midpoint)
@@ -778,8 +754,7 @@ def get_geometric_midpoint(pt_x, pt_y, as_geom=False):
     midpoint = (pt_x_.x + pt_y_.x) / 2, (pt_x_.y + pt_y_.y) / 2
 
     if as_geom:
-        from shapely.geometry import Point
-        midpoint = Point(midpoint)
+        midpoint = shapely.geometry.Point(midpoint)
 
     return midpoint
 
@@ -790,7 +765,8 @@ def get_geometric_midpoint_calc(pt_x, pt_y, as_geom=False):
 
     See also
     [`GEOM-GGMC-1 <http://code.activestate.com/recipes/577713-midpoint-of-two-gps-points/>`_]
-    and [`GEOM-GGMC-2 <http://www.movable-type.co.uk/scripts/latlong.html>`_].
+    and
+    [`GEOM-GGMC-2 <http://www.movable-type.co.uk/scripts/latlong.html>`_].
 
     :param pt_x: a point
     :type pt_x: shapely.geometry.Point or list or tuple or numpy.ndarray
@@ -807,8 +783,7 @@ def get_geometric_midpoint_calc(pt_x, pt_y, as_geom=False):
 
         >>> from pyhelpers.geom import get_geometric_midpoint_calc
 
-        >>> pt_1 = 1.5429, 52.6347
-        >>> pt_2 = 1.4909, 52.6271
+        >>> pt_1, pt_2 = (1.5429, 52.6347), (1.4909, 52.6271)
 
         >>> geometric_midpoint = get_geometric_midpoint_calc(pt_1, pt_2)
         >>> print(geometric_midpoint)
@@ -837,12 +812,40 @@ def get_geometric_midpoint_calc(pt_x, pt_y, as_geom=False):
     midpoint = np.degrees(long_3), np.degrees(lat_3)
 
     if as_geom:
-        from shapely.geometry import Point
-        midpoint = Point(midpoint)
+        midpoint = shapely.geometry.Point(midpoint)
 
     return midpoint
 
 
+def get_rectangle_centroid(rectangle_geom):
+    """
+    Get coordinates of the centroid of a rectangle
+
+    :param rectangle_geom: polygon or multipolygon geometry object
+    :type rectangle_geom: shapely.geometry.Polygon or shapely.geometry.MultiPolygon
+    :return: coordinates [Longitude, Latitude] or [Easting, Northing]
+    :rtype: list
+
+    **Test**::
+
+        >>> import shapely.geometry
+        >>> from pyhelpers.geom import get_rectangle_centroid
+
+        >>> rectangle = shapely.geometry.Polygon([[0, 0], [0, 1], [1, 1], [1, 0]])
+
+        >>> rec_cen = get_rectangle_centroid(rectangle)
+
+        >>> print(rec_cen)
+        [0.5, 0.5]
+    """
+
+    ll_lon, ll_lat, ur_lon, ur_lat = rectangle_geom.bounds
+
+    rec_centre = [np.round((ur_lon + ll_lon) / 2, 4), np.round((ll_lat + ur_lat) / 2, 4)]
+
+    return rec_centre
+
+
 def get_square_vertices(ctr_x, ctr_y, side_length, rotation_theta=0):
     """
     Get the four vertices of a square given its centre and side length.
@@ -902,8 +905,7 @@ def get_square_vertices(ctr_x, ctr_y, side_length, rotation_theta=0):
 
 def get_square_vertices_calc(ctr_x, ctr_y, side_length, rotation_theta=0):
     """
-    Get the four vertices of a square given its centre and side length
-    (by elementary calculation).
+    Get the four vertices of a square given its centre and side length (by elementary calculation).
 
     See also [`GEOM-GSVC-1 <https://math.stackexchange.com/questions/1490115>`_].
 
@@ -962,7 +964,7 @@ def get_square_vertices_calc(ctr_x, ctr_y, side_length, rotation_theta=0):
     return vertices
 
 
-""" Geometric data visualisation -------------------------------------------------------- """
+""" Geometric data visualisation ------------------------------------------------------------- """
 
 
 # Sketch
@@ -986,7 +988,7 @@ def sketch_square(ctr_x, ctr_y, side_length=None, rotation_theta=0, annotation=F
     :param annot_font_size: font size annotation texts, defaults to ``12``
     :type annot_font_size: int
     :param fig_size: figure size, defaults to ``(6.4, 4.8)``
-    :type fig_size: tuple, list
+    :type fig_size: tuple or list
     :param ret_vertices: whether to return the vertices of the square, defaults to ``False``
     :type ret_vertices: bool
     :param kwargs: optional parameters of `matplotlib.axes.Axes.annotate`_
@@ -1001,11 +1003,10 @@ def sketch_square(ctr_x, ctr_y, side_length=None, rotation_theta=0, annotation=F
         >>> import matplotlib.pyplot as plt
         >>> from pyhelpers.geom import sketch_square
 
-        >>> ctr_1, ctr_2 = 1, 1
+        >>> c1, c2 = 1, 1
         >>> side_len = 2
 
-        >>> sketch_square(ctr_1, ctr_2, side_len, rotation_theta=0, annotation=True,
-        ...               fig_size=(5, 5))
+        >>> sketch_square(c1, c2, side_len, rotation_theta=0, annotation=True, fig_size=(5, 5))
         >>> plt.show()
 
     The above exmaple is illustrated in :numref:`sketch-square-1`:
@@ -1020,8 +1021,7 @@ def sketch_square(ctr_x, ctr_y, side_length=None, rotation_theta=0, annotation=F
 
     .. code-block:: python
 
-        >>> sketch_square(ctr_1, ctr_2, side_len, rotation_theta=75, annotation=True,
-        ...               fig_size=(5, 5))
+        >>> sketch_square(c1, c2, side_len, rotation_theta=75, annotation=True, fig_size=(5, 5))
         >>> plt.show()
 
     This second example is illustrated in :numref:`sketch-square-2`:
