@@ -2,6 +2,7 @@
 Miscellaneous operations.
 """
 
+import ast
 import collections.abc
 import datetime
 import inspect
@@ -21,20 +22,19 @@ import pandas as pd
 import requests
 import tqdm
 
-""" General use ------------------------------------------------------------------------- """
+""" General use ------------------------------------------------------------------------------ """
 
 
 def confirmed(prompt=None, confirmation_required=True, resp=False):
     """
     Type to confirm whether to proceed or not.
 
-    See also [`OPS-C-1
-    <https://code.activestate.com/recipes/541096-prompt-the-user-for-confirmation/>`_].
+    See also
+    [`OPS-C-1 <https://code.activestate.com/recipes/541096-prompt-the-user-for-confirmation/>`_].
 
     :param prompt: a message that prompts an response (Yes/No), defaults to ``None``
     :type prompt: str or None
-    :param confirmation_required: whether to require users to confirm and proceed,
-        defaults to ``True``
+    :param confirmation_required: whether to require users to confirm and proceed, defaults to ``True``
     :type confirmation_required: bool
     :param resp: default response, defaults to ``False``
     :type resp: bool
@@ -45,8 +45,7 @@ def confirmed(prompt=None, confirmation_required=True, resp=False):
 
         >>> from pyhelpers.ops import confirmed
 
-        >>> if confirmed(prompt="Create Directory?", resp=True):
-        ...     print("Passed.")
+        >>> if confirmed(prompt="Create Directory?", resp=True): print("Passed.")
         Create Directory? [No]|Yes: yes
         Passed.
     """
@@ -88,8 +87,7 @@ def get_obj_attr(obj, col_names=None):
 
         >>> from pyhelpers import get_obj_attr, PostgreSQL
 
-        >>> postgres = PostgreSQL(host='localhost', port=5432, username='postgres',
-        ...                       database_name='postgres')
+        >>> postgres = PostgreSQL('localhost', 5432, 'postgres', database_name='postgres')
         Password (postgres@localhost:5432): ***
         Connecting postgres:***@localhost:5432/postgres ... Successfully.
 
@@ -115,7 +113,43 @@ def get_obj_attr(obj, col_names=None):
     return attrs_tbl
 
 
-""" Basic data manipulation ------------------------------------------------------------- """
+def eval_dtype(str_val):
+    """
+    Convert a string to its intrinsic data type.
+
+    :param str_val: a string-type variable
+    :type str_val: str
+    :return: converted value
+    :rtype: any
+
+    **Tests**::
+
+        >>> from pyhelpers.ops import eval_dtype
+
+        >>> val_1 = '1'
+        >>> origin_val = eval_dtype(val_1)
+        >>> type(origin_val)
+        int
+        >>> print(origin_val)
+        1
+
+        >>> val_2 = '1.1.1'
+        >>> origin_val = eval_dtype(val_2)
+        >>> type(origin_val)
+        str
+        >>> print(origin_val)
+        1.1.1
+    """
+
+    try:
+        val = ast.literal_eval(str_val)
+    except (ValueError, SyntaxError):
+        val = str_val
+
+    return val
+
+
+""" Basic data manipulation ------------------------------------------------------------------ """
 
 
 # Iterable
@@ -141,7 +175,7 @@ def split_list_by_size(lst, sub_len):
         >>> sub_lst_len = 3
 
         >>> lists = split_list_by_size(lst_, sub_lst_len)
-        >>> print(list(lists))
+        >>> list(lists)
         [[0, 1, 2], [3, 4, 5], [6, 7, 8], [9]]
     """
 
@@ -170,7 +204,7 @@ def split_list(lst, num_of_sub):
         >>> num_of_sub_lists = 3
 
         >>> lists = list(split_list(lst_, num_of_sub_lists))
-        >>> print(list(lists))
+        >>> list(lists)
         [[0, 1, 2, 3], [4, 5, 6, 7], [8, 9]]
     """
 
@@ -200,8 +234,7 @@ def split_iterable(iterable, chunk_size):
         >>> lst = list(range(0, 10))
         >>> size_of_chunk = 3
 
-        >>> for lst_ in split_iterable(lst, size_of_chunk):
-        ...     print(list(lst_))
+        >>> for lst_ in split_iterable(lst, size_of_chunk): print(list(lst_))
         [0, 1, 2]
         [3, 4, 5]
         [6, 7, 8]
@@ -209,8 +242,7 @@ def split_iterable(iterable, chunk_size):
 
         >>> lst = pandas.Series(range(0, 20))
         >>> size_of_chunk = 5
-        >>> for lst_ in split_iterable(lst, size_of_chunk):
-        ...     print(list(lst_))
+        >>> for lst_ in split_iterable(lst, size_of_chunk): print(list(lst_))
         [0, 1, 2, 3, 4]
         [5, 6, 7, 8, 9]
         [10, 11, 12, 13, 14]
@@ -305,25 +337,25 @@ def get_all_values_from_nested_dict(key, target_dict):
         >>> key_ = 'key'
         >>> target_dict_ = {'key': 'val'}
         >>> val = get_all_values_from_nested_dict(key_, target_dict_)
-        >>> print(list(val))
+        >>> list(val)
         [['val']]
 
         >>> key_ = 'k1'
         >>> target_dict_ = {'key': {'k1': 'v1', 'k2': 'v2'}}
         >>> val = get_all_values_from_nested_dict(key_, target_dict_)
-        >>> print(list(val))
+        >>> list(val)
         [['v1']]
 
         >>> key_ = 'k1'
         >>> target_dict_ = {'key': {'k1': ['v1', 'v1_1']}}
         >>> val = get_all_values_from_nested_dict(key_, target_dict_)
-        >>> print(list(val))
+        >>> list(val)
         [['v1', 'v1_1']]
 
         >>> key_ = 'k2'
         >>> target_dict_ = {'key': {'k1': 'v1', 'k2': ['v2', 'v2_1']}}
         >>> val = get_all_values_from_nested_dict(key_, target_dict_)
-        >>> print(list(val))
+        >>> list(val)
         [['v2', 'v2_1']]
     """
 
@@ -419,7 +451,7 @@ def detect_nan_for_str_column(data_frame, column_names=None):
         >>> df.iloc[3, 1] = numpy.nan
 
         >>> nan_col_pos = detect_nan_for_str_column(df, column_names=None)
-        >>> print(list(nan_col_pos))
+        >>> list(nan_col_pos)
         [1]
     """
 
@@ -503,11 +535,12 @@ def parse_csr_matrix(path_to_csr, verbose=False, **kwargs):
     :param verbose: whether to print relevant information in console as the function runs,
         defaults to ``False``
     :type verbose: bool or int
-    :param kwargs: optional arguments of
-        `numpy.load <https://numpy.org/doc/stable/reference/generated/numpy.load>`_
+    :param kwargs: optional parameters of `numpy.load`_
     :return: a compressed sparse row
     :rtype: scipy.sparse.csr.csr_matrix
 
+    .. _`numpy.load`: https://numpy.org/doc/stable/reference/generated/numpy.load
+
     **Example**::
 
         >>> import numpy
@@ -557,7 +590,95 @@ def parse_csr_matrix(path_to_csr, verbose=False, **kwargs):
         print("Failed. {}".format(e)) if verbose else ""
 
 
-""" Basic computation ------------------------------------------------------------------- """
+def swap_cols(array, c1, c2, as_list=False):
+    """
+    Swap positions of two columns in an array.
+
+    :param array: an array
+    :type array: numpy.ndarray
+    :param c1: index of a column
+    :type c1: int
+    :param c2: index of another column
+    :type c2: int
+    :param as_list: whether to return a list
+    :type as_list: bool
+    :return: a new array/list in which the positions of the c1-th and c2-th columns are swapped
+    :rtype: numpy.ndarray or list
+
+    **Test**::
+
+        >>> import numpy
+        >>> from pyhelpers.ops import swap_cols
+
+        >>> arr = numpy.array([[55.95615851, -2.96251228],
+        ...                    [55.95705685, -2.96253458],
+        ...                    [55.95706935, -2.96093324],
+        ...                    [55.956171  , -2.96091098]])
+
+        >>> new_arr = swap_cols(arr, 0, 1)
+
+        >>> type(new_arr)
+        numpy.ndarray
+        >>> print(new_arr)
+        [[-2.96251228 55.95615851]
+         [-2.96253458 55.95705685]
+         [-2.96093324 55.95706935]
+         [-2.96091098 55.956171  ]]
+    """
+
+    array[:, c1], array[:, c2] = array[:, c2], array[:, c1].copy()
+
+    if as_list:
+        array = list(array)
+
+    return array
+
+
+def swap_rows(array, r1, r2, as_list=False):
+    """
+    Swap positions of two rows in an array.
+
+    :param array: an array
+    :type array: numpy.ndarray
+    :param r1: index of a row
+    :type r1: int
+    :param r2: index of another row
+    :type r2: int
+    :param as_list: whether to return a list
+    :type as_list: bool
+    :return: a new array/list in which the positions of the r1-th and r2-th rows are swapped
+    :rtype: numpy.ndarray or list
+
+    **Test**::
+
+        >>> import numpy
+        >>> from pyhelpers.ops import swap_rows
+
+        >>> arr = numpy.array([[55.95615851, -2.96251228],
+        ...                    [55.95705685, -2.96253458],
+        ...                    [55.95706935, -2.96093324],
+        ...                    [55.956171  , -2.96091098]])
+
+        >>> new_arr = swap_rows(arr, 0, 1)
+
+        >>> type(new_arr)
+        numpy.ndarray
+        >>> print(new_arr)
+        [[-2.96253458 55.95705685]
+         [-2.96251228 55.95615851]
+         [-2.96093324 55.95706935]
+         [-2.96091098 55.956171  ]]
+    """
+
+    array[r1, :], array[r2, :] = array[r2, :], array[r1, :].copy()
+
+    if as_list:
+        array = list(array)
+
+    return array
+
+
+""" Basic computation ------------------------------------------------------------------------ """
 
 
 def get_extreme_outlier_bounds(num_dat, k=1.5):
@@ -597,11 +718,11 @@ def interquartile_range(num_dat):
     """
     Calculate interquartile range.
 
-    This function may be an alternative to `scipy.stats.iqr
-    <https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.iqr.html>`_.
+    This function may be an alternative to
+    `scipy.stats.iqr <https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.iqr.html>`_.
 
     :param num_dat: an array of numbers
-    :type num_dat: array-like
+    :type num_dat: numpy.ndarry or list or tuple
     :return: interquartile range of ``num_dat``
     :rtype: float
 
@@ -630,8 +751,7 @@ def find_closest_date(date, lookup_dates, as_datetime=False, fmt='%Y-%m-%d %H:%M
     :type date: str or datetime.datetime
     :param lookup_dates: an array of dates
     :type lookup_dates: list or tuple or collections.abc.Iterable
-    :param as_datetime: whether to return a datetime.datetime-formatted date,
-        defaults to ``False``
+    :param as_datetime: whether to return a datetime.datetime-formatted date, defaults to ``False``
     :type as_datetime: bool
     :param fmt: datetime format, defaults to ``'%Y-%m-%d %H:%M:%S.%f'``
     :type fmt: str
@@ -669,7 +789,7 @@ def find_closest_date(date, lookup_dates, as_datetime=False, fmt='%Y-%m-%d %H:%M
     return closest_date
 
 
-""" Graph plotting ---------------------------------------------------------------------- """
+""" Graph plotting --------------------------------------------------------------------------- """
 
 
 def cmap_discretisation(cmap, n_colours):
@@ -679,18 +799,15 @@ def cmap_discretisation(cmap, n_colours):
     See also [`OPS-CD-1
     <http://sensitivecities.com/so-youd-like-to-make-a-map-using-python-EN.html#.WbpP0T6GNQB>`_].
 
-    :param cmap: a colormap instance, such as built-in `colormaps`_ accessible
-        via `matplotlib.cm.get_cmap`_
+    :param cmap: a colormap instance, e.g. built-in `colormaps`_ accessible via `matplotlib.cm.get_cmap`_
     :type cmap: matplotlib.colors.ListedColormap
     :param n_colours: number of colours
     :type n_colours: int
     :return: a discrete colormap from (the continuous) ``cmap``
     :rtype: matplotlib.colors.LinearSegmentedColormap
 
-    .. _`colormaps`:
-        https://matplotlib.org/tutorials/colors/colormaps.html
-    .. _`matplotlib.cm.get_cmap`:
-        https://matplotlib.org/api/cm_api.html#matplotlib.cm.get_cmap
+    .. _`colormaps`: https://matplotlib.org/tutorials/colors/colormaps.html
+    .. _`matplotlib.cm.get_cmap`: https://matplotlib.org/api/cm_api.html#matplotlib.cm.get_cmap
 
     **Example**::
 
@@ -702,8 +819,9 @@ def cmap_discretisation(cmap, n_colours):
         >>> cm_accent = cmap_discretisation(matplotlib.cm.get_cmap('Accent'), n_colours=5)
 
         >>> fig, ax = plt.subplots(figsize=(10, 2))
-        >>> ax.imshow(numpy.resize(range(100), (5, 100)), cmap=cm_accent,
-        ...           interpolation='nearest')
+
+        >>> ax.imshow(numpy.resize(range(100), (5, 100)), cmap=cm_accent, interpolation='nearest')
+
         >>> plt.axis('off')
         >>> plt.tight_layout()
         >>> plt.show()
@@ -719,8 +837,10 @@ def cmap_discretisation(cmap, n_colours):
         :py:func:`cmap_discretisation()<pyhelpers.ops.cmap_discretisation>`.
     """
 
+    import matplotlib.cm
+    import matplotlib.colors
+
     if isinstance(cmap, str):
-        import matplotlib.cm
         cmap = matplotlib.cm.get_cmap(cmap)
 
     colours_i = np.concatenate((np.linspace(0, 1., n_colours), (0., 0., 0., 0.)))
@@ -729,12 +849,11 @@ def cmap_discretisation(cmap, n_colours):
     c_dict = {}
 
     for ki, key in enumerate(('red', 'green', 'blue')):
-        c_dict[key] = [(indices[x], colours_rgba[x - 1, ki], colours_rgba[x, ki])
-                       for x in range(n_colours + 1)]
+        c_dict[key] = [
+            (indices[x], colours_rgba[x - 1, ki], colours_rgba[x, ki]) for x in range(n_colours + 1)
+        ]
 
-    import matplotlib.colors
-    colour_map = matplotlib.colors.LinearSegmentedColormap(
-        cmap.name + '_%d' % n_colours, c_dict, 1024)
+    colour_map = matplotlib.colors.LinearSegmentedColormap(cmap.name + '_%d' % n_colours, c_dict, 1024)
 
     return colour_map
 
@@ -749,23 +868,19 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
     See also [`OPS-CBI-1
     <http://sensitivecities.com/so-youd-like-to-make-a-map-using-python-EN.html#.WbpP0T6GNQB>`_].
 
-    :param cmap: a colormap instance, such as built-in `colormaps`_ accessible
-        via `matplotlib.cm.get_cmap`_
+    :param cmap: a colormap instance, e.g. built-in `colormaps`_ accessible via `matplotlib.cm.get_cmap`_
     :type cmap: matplotlib.colors.ListedColormap
     :param n_colours: number of colours
     :type n_colours: int
     :param labels: a list of labels for the colour bar, defaults to ``None``
     :type labels: list or None
-    :param kwargs: optional arguments of `matplotlib.pyplot.colorbar`_
+    :param kwargs: optional parameters of `matplotlib.pyplot.colorbar`_
     :return: a colour bar object
     :rtype: matplotlib.colorbar.Colorbar
 
-    .. _`colormaps`:
-        https://matplotlib.org/tutorials/colors/colormaps.html
-    .. _`matplotlib.cm.get_cmap`:
-        https://matplotlib.org/api/cm_api.html#matplotlib.cm.get_cmap
-    .. _`matplotlib.pyplot.colorbar`:
-        https://matplotlib.org/api/_as_gen/matplotlib.pyplot.colorbar.html
+    .. _`colormaps`: https://matplotlib.org/tutorials/colors/colormaps.html
+    .. _`matplotlib.cm.get_cmap`: https://matplotlib.org/api/cm_api.html#matplotlib.cm.get_cmap
+    .. _`matplotlib.pyplot.colorbar`: https://matplotlib.org/api/_as_gen/matplotlib.pyplot.colorbar.html
 
     **Examples**::
 
@@ -774,9 +889,14 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
         >>> from pyhelpers.ops import colour_bar_index
 
         >>> plt.figure(figsize=(2, 6))
+
         >>> cbar = colour_bar_index(cmap=matplotlib.cm.get_cmap('Accent'), n_colours=5)
-        >>> cbar.ax.tick_params(labelsize=18)
-        >>> plt.axis('off')
+
+        >>> plt.xticks(fontsize=12)
+        >>> plt.yticks(fontsize=12)
+        >>> cbar.ax.tick_params(labelsize=14)
+
+        >>> # plt.axis('off')
         >>> plt.tight_layout()
         >>> plt.show()
 
@@ -784,18 +904,24 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
 
     .. figure:: ../_images/colour-bar-index-1.*
         :name: colour-bar-index-1
-        :width: 17%
+        :align: center
+        :width: 23%
 
-        An example of colour bar with numerical index, created by
-        :py:func:`colour_bar_index()<pyhelpers.ops.colour_bar_index>`.
+        An example of colour bar with numerical index,
+        created by :py:func:`colour_bar_index()<pyhelpers.ops.colour_bar_index>`.
 
     .. code-block:: python
 
         >>> plt.figure(figsize=(2, 6))
-        >>> cbar = colour_bar_index(matplotlib.cm.get_cmap('Accent'), n_colours=5,
-        ...                         labels=list('abcde'))
-        >>> cbar.ax.tick_params(labelsize=18)
-        >>> plt.axis('off')
+
+        >>> labels_ = list('abcde')
+        >>> cbar = colour_bar_index(matplotlib.cm.get_cmap('Accent'), n_colours=5, labels=labels_)
+
+        >>> plt.xticks(fontsize=12)
+        >>> plt.yticks(fontsize=12)
+        >>> cbar.ax.tick_params(labelsize=14)
+
+        >>> # plt.axis('off')
         >>> plt.tight_layout()
         >>> plt.show()
 
@@ -803,20 +929,22 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
 
     .. figure:: ../_images/colour-bar-index-2.*
         :name: colour-bar-index-2
-        :width: 17%
+        :align: center
+        :width: 23%
 
-        An example of colour bar with textual index, created by
-        :py:func:`colour_bar_index()<pyhelpers.ops.colour_bar_index>`.
+        An example of colour bar with textual index,
+        created by :py:func:`colour_bar_index()<pyhelpers.ops.colour_bar_index>`.
     """
 
+    import matplotlib.cm
+    import matplotlib.pyplot
+
     cmap = cmap_discretisation(cmap, n_colours)
 
-    import matplotlib.cm
     mappable = matplotlib.cm.ScalarMappable(cmap=cmap)
     mappable.set_array(np.array([]))
     mappable.set_clim(-0.5, n_colours + 0.5)
 
-    import matplotlib.pyplot
     colour_bar = matplotlib.pyplot.colorbar(mappable, **kwargs)
     colour_bar.set_ticks(np.linspace(0, n_colours, n_colours))
     colour_bar.set_ticklabels(range(n_colours))
@@ -827,7 +955,7 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
     return colour_bar
 
 
-""" Web scraping ------------------------------------------------------------------------ """
+""" Web scraping ----------------------------------------------------------------------------- """
 
 
 def is_network_connected():
@@ -841,8 +969,7 @@ def is_network_connected():
 
         >>> from pyhelpers.ops import is_network_connected
 
-        >>> is_network_connected()
-        >>> # if the machine is currently connected to the Internet
+        >>> is_network_connected()  # assuming the machine is currently connected to the Internet
         True
     """
 
@@ -900,13 +1027,11 @@ def fake_requests_headers(randomized=False):
 
         >>> fake_headers_ = fake_requests_headers()
         >>> print(fake_headers_)
-        {'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 '
-                       '(KHTML, like Gecko) Chrome/41.0.2227.0 Safari/537.36'}
+        {'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ch...
 
         >>> fake_headers_ = fake_requests_headers(randomized=True)
         >>> print(fake_headers_)
-        {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36'
-                       ' (KHTML, like Gecko) Chrome/36.0.1944.0 Safari/537.36'}
+        {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36 (KHTML ...
 
     .. note::
 
@@ -930,8 +1055,7 @@ def fake_requests_headers(randomized=False):
     return fake_headers
 
 
-def download_file_from_url(url, path_to_file, wait_to_retry=3600, random_header=False,
-                           **kwargs):
+def download_file_from_url(url, path_to_file, wait_to_retry=3600, random_header=False, **kwargs):
     """
     Download an object available at a given URL.
 
@@ -945,17 +1069,30 @@ def download_file_from_url(url, path_to_file, wait_to_retry=3600, random_header=
     :type wait_to_retry: int or float
     :param random_header: whether to go for a random agent, defaults to ``False``
     :type random_header: bool
-    :param kwargs: optional arguments of
-        `open <https://docs.python.org/3/library/functions.html#open>`_
+    :param kwargs: optional parameters of `open`_
+
+    .. _`open`: https://docs.python.org/3/library/functions.html#open
 
     **Example**::
 
         >>> from pyhelpers.dir import cd
+        >>> from PIL import Image
         >>> from pyhelpers.ops import download_file_from_url
 
         >>> logo_url = 'https://www.python.org/static/community_logos/python-logo-master-v3-TM.png'
+        >>> path_to_img = cd("tests", "images", "python-logo.png")
 
-        >>> download_file_from_url(logo_url, cd("tests\\images", "python-logo.png"))
+        >>> download_file_from_url(logo_url, path_to_img)
+
+        >>> img = Image.open(path_to_img)
+        >>> img.show()  # as illustrated below
+
+    .. figure:: ../_images/python-logo.*
+        :name: python-logo
+        :align: center
+        :width: 65%
+
+        The Python Logo.
     """
 
     headers = fake_requests_headers(randomized=random_header)
@@ -977,8 +1114,8 @@ def download_file_from_url(url, path_to_file, wait_to_retry=3600, random_header=
             os.makedirs(directory)
 
     with open(path_to_file, mode='wb', **kwargs) as f:
-        for data in tqdm.tqdm(resp.iter_content(block_size, decode_unicode=True),
-                              total=total_size // block_size, unit='MB'):
+        temp = resp.iter_content(block_size, decode_unicode=True)
+        for data in tqdm.tqdm(temp, total=total_size // block_size, unit='MB'):
             wrote = wrote + len(data)
             try:
                 f.write(data)
